@@ -1,7 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-our $VERSION = '7.07_01';
+our $VERSION = '7.11_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -10,7 +10,7 @@ use File::Basename;
 BEGIN { our @ISA = qw(File::Spec); }
 
 # We need $Verbose
-use ExtUtils::MakeMaker qw($Verbose write_file_via_tmp neatvalue _sprintf562);
+use ExtUtils::MakeMaker qw($Verbose neatvalue _sprintf562);
 
 use ExtUtils::MakeMaker::Config;
 
@@ -23,7 +23,6 @@ my $Updir   = __PACKAGE__->updir;
 
 my $METASPEC_URL = 'https://metacpan.org/pod/CPAN::Meta::Spec';
 my $METASPEC_V = 2;
-my $STASHDIR = File::Spec->catdir('blib', '_eumm');
 
 =head1 NAME
 
@@ -376,16 +375,7 @@ at build-time.
 
 sub stashmeta {
     my($self, $text, $file) = @_;
-    require File::Path;
-    -d $STASHDIR or die "$STASHDIR: $!" unless File::Path::mkpath($STASHDIR,0,0777);
-    my $stashfile = File::Spec->catfile($STASHDIR, $file);
-    write_file_via_tmp($stashfile, [ $text ]);
-    my $qlfile = $self->quote_literal($file);
-    my $qlstashfile = $self->quote_literal($stashfile);
-    (
-        sprintf('-$(NOECHO) $(RM_F) %s', $qlfile),
-        sprintf('-$(NOECHO) $(CP) %s %s', $qlstashfile, $qlfile),
-    );
+    $self->echo($text, $file, { allow_variables => 0, append => 0 });
 }
 
 
@@ -725,7 +715,7 @@ clean :: clean_subdirs
 	my $file = $_;
 	map { $file.$_ } $self->{OBJ_EXT}, qw(.def _def.old .bs .bso .exp .base);
     } $self->_xs_list_basenames;
-    my @dirs  = qw(blib _eumm);
+    my @dirs  = qw(blib);
 
     # Normally these are all under blib but they might have been
     # redefined.
@@ -1102,12 +1092,16 @@ CMD
     return $manify;
 }
 
-sub _has_cpan_meta {
-    return eval {
-      require CPAN::Meta;
-      CPAN::Meta->VERSION(2.112150);
-      1;
-    };
+{
+    my $has_cpan_meta;
+    sub _has_cpan_meta {
+        return $has_cpan_meta if defined $has_cpan_meta;
+        return $has_cpan_meta = !!eval {
+            require CPAN::Meta;
+            CPAN::Meta->VERSION(2.112150);
+            1;
+        };
+    }
 }
 
 =head3 metafile_target
