@@ -111,6 +111,20 @@ ok is_odd(1);
 ok !is_odd(2);
 END
 
+my $PLUS1_C = <<'EOF';
+#ifdef __cplusplus
+extern "C" {
+int plus1(int i)
+#else
+int plus1(i)
+int i;
+#endif
+{ return i + 1; }
+#ifdef __cplusplus
+}
+#endif
+EOF
+
 my %Files = (
   'lib/XS/Test.pm' => $PM_TEST,
   $typemap => '',
@@ -140,7 +154,7 @@ $label2files{subdirs} = +{
   %{ $label2files{'basic'} }, # make copy
   'Makefile.PL' => sprintf(
     $MAKEFILEPL, 'Test', 'Test.pm', qq{'$typemap'},
-    q{DEFINE => '-DINVAR=input',},
+    q{DEFINE => '-DINVAR=input', INC => "-Inewline\n", LIBS => "-Lnewline\n",},
   ),
   'Other/Makefile.PL' => sprintf($MAKEFILEPL, 'Other', 'Other.pm', qq{}, ''),
   'Other/Other.pm' => $PM_OTHER,
@@ -149,6 +163,46 @@ $label2files{subdirs} = +{
 };
 virtual_rename('subdirs', 'lib/XS/Test.pm', 'Test.pm');
 
+# to mimic behaviour of Unicode-LineBreak version 2015.07.16
+$label2files{subdirscomplex} = +{
+  %{ $label2files{'subdirs'} }, # make copy
+  'Other/Makefile.PL' => sprintf(
+    $MAKEFILEPL,
+    'Other', 'Other.pm', qq{},
+    <<'EOF',
+C => [qw(lib$(DIRFILESEP)file.c)],
+OBJECT => 'lib$(DIRFILESEP)file$(OBJ_EXT)',
+EOF
+  ) . <<'EOF',
+sub MY::c_o {
+  package MY;
+  my $self = shift;
+  my $inherited = $self->SUPER::c_o(@_);
+  $inherited =~ s{(:\n\t)(.*(?:\n\t.*)*)}
+      { $1 . $self->cd('lib', split /(?<!\\)\n\t/, $2) }eg;
+  $inherited =~ s{(\s)(\$\*\.c\s)}
+      { "$1..\$(DIRFILESEP)$2" }eg;
+  $inherited;
+}
+
+sub MY::top_targets {
+  <<'SNIP';
+all :: lib$(DIRFILESEP)file$(OBJ_EXT)
+	$(NOECHO) $(NOOP)
+
+config ::
+	$(NOECHO) $(NOOP)
+
+pure_all ::
+	$(NOECHO) $(NOOP)
+SNIP
+}
+EOF
+  'Other/lib/file.c' => $PLUS1_C,
+};
+delete $label2files{subdirscomplex}{'Other/Other.xs'};
+delete $label2files{subdirscomplex}{'t/is_odd.t'};
+
 $label2files{subdirsstatic} = +{
   %{ $label2files{'subdirs'} }, # make copy
   'Makefile.PL' => sprintf(
@@ -206,8 +260,13 @@ $label2files{xsbuild} = +{
       },
     },
   ),
-  'lib/XS/Other.xs' => $XS_OTHER . <<EOF,
-\nint
+
+  'lib/XS/Other.xs' => <<EOF,
+#ifdef __cplusplus
+extern "C" { int plus1(int); }
+#endif
+$XS_OTHER
+int
 plus1(input)
        int     input
    CODE:
@@ -215,7 +274,9 @@ plus1(input)
    OUTPUT:
        RETVAL
 EOF
-  'lib/XS/plus1.c' => 'int plus1(i) int i; { return i + 1; }',
+
+  'lib/XS/plus1.c' => $PLUS1_C,
+
   't/is_odd.t' => <<'END',
 #!/usr/bin/perl -w
 use Test::More tests => 4;
@@ -224,6 +285,7 @@ ok is_odd(1);
 ok !is_odd(2);
 is XS::Other::plus1(3), 4;
 END
+
 };
 
 sub virtual_rename {
@@ -260,6 +322,7 @@ sub list_dynamic {
     $^O ne 'MSWin32' ? (
         [ 'bscode', '', '' ],
         [ 'bscodemulti', '', '' ],
+        [ 'subdirscomplex', '', '' ],
     ) : (), # DynaLoader different
     [ 'subdirs', '', '' ],
     [ 'subdirsstatic', ' LINKTYPE=dynamic', ' LINKTYPE=dynamic' ],
